##
##  perl-ssl.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   versions of individual parts
%define       V_perl              5.22
%define       V_net_ssleay        1.94
%define       V_crypt_ssleay      0.73_06
%define       V_io_socket_ssl     1.94

#   package information
Name:         perl-ssl
Summary:      Perl Modules for use with SSL
URL:          http://www.cpan.org/
Vendor:       Perl Community
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Perl
License:      GPL/Artistic
Version:      %{V_perl}
Release:      20240108

#   list of sources
Source0:      http://www.cpan.org/authors/id/C/CH/CHRISN/Net-SSLeay-%{V_net_ssleay}.tar.gz
Source1:      http://www.cpan.org/authors/id/N/NA/NANIS/Crypt-SSLeay-%{V_crypt_ssleay}.tar.gz
Source2:      http://www.cpan.org/authors/id/S/SU/SULLR/IO-Socket-SSL-%{V_io_socket_ssl}.tar.gz
Patch0:       perl-ssl.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl >= %{V_perl}, perl-openpkg >= %{V_perl}-20040126
PreReq:       OpenPKG, openpkg >= 20160101, perl >= %{V_perl}
BuildPreReq:  openssl, perl-ds, perl-mail
PreReq:       openssl, perl-ds, perl-mail

%description
    Various Perl modules for use with SSL/TLS (OpenSSL):
    - Net::SSLeay (%{V_net_ssleay})
    - Crypt::SSLeay (%{V_crypt_ssleay})
    - IO::Socket::SSL (%{V_io_socket_ssl})

%track
    prog perl-ssl:Crypt-SSLeay = {
        version   = %{V_crypt_ssleay}
        url       = http://www.cpan.org/authors/id/N/NA/NANIS/
        regex     = Crypt-SSLeay-(__VER__)\.tar\.gz
    }
    prog perl-ssl:IO-Socket-SSL = {
        version   = %{V_io_socket_ssl}
        url       = http://www.cpan.org/authors/id/S/SU/SULLR/
        regex     = IO-Socket-SSL-(\d+\.\d\d)\.tar\.gz
    }
    prog perl-ssl:Net-SSLeay = {
        version   = %{V_net_ssleay}
        url       = http://www.cpan.org/authors/id/C/CH/CHRISN/
        regex     = Net-SSLeay-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1
    %setup -q -T -D -a 2
    %patch -p0

%build

%install
    OPENSSL_PREFIX="%{l_prefix}"
    export OPENSSL_PREFIX

    %{l_prefix}/bin/perl-openpkg prepare

    %{l_prefix}/bin/perl-openpkg -d %{SOURCE0} \
        --args "%{l_prefix} -- #" \
        configure build install

    ( cd Crypt-SSLeay-%{V_crypt_ssleay}
      %{l_shtool} subst \
          -e 's;-lz;%{l_ldflags} -lz;' \
          Makefile.PL
    ) || exit $?
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE1}  configure build install

    %{l_prefix}/bin/perl-openpkg -d %{SOURCE2}  configure build install

    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

